@@ -19,7 +19,7 @@ extern "C" {
 // ------------------------------------------------------------------------------------------------|
 void ggm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[], int *p, 
             double K_hat[], double p_links[], int *n,
-            double *v1, double *v2, double *lambda, double *g_prior, int *print )
+            double *v1, double *v2, double *lambda, double g_prior[], int *print )
 {
     double var_1    = *v1;
     double var_2    = *v2;
@@ -28,15 +28,15 @@ void ggm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[],
     double a_gam         = 0.5 * *n + 1.0; 
     double sqrt_v1       = sqrt( var_1 );
     double sqrt_v2       = sqrt( var_2 );
-    double g_prior_c     = *g_prior;
-    double one_g_prior_c = 1.0 - g_prior_c;
+//    double g_prior_c     = *g_prior;
+//    double one_g_prior_c = 1.0 - g_prior_c;
 
     double alpha = 1.0, beta = 0.0, alpha1 = -1.0;
     double w1, w2, prob_e, inv_V_ij, sigmaii_inv, Sii_lambda, b_gam, gam, K0ii;
     
 	int print_c = *print, iteration = *iter, burn_in = *burnin;
 	int info, one = 1, dim = *p, pxp = dim * dim;
-	int p1 = dim - 1, p1xp1 = p1 * p1, i, row_i, ii, k, k_p1, G_ij;
+	int p1 = dim - 1, p1xp1 = p1 * p1, i, row_i, ii, k, ik, k_p1, G_ij;
 	
 	char transT = 'T', transN = 'N', sideU = 'U', diagN = 'N';																	
 	
@@ -123,7 +123,7 @@ void ggm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[],
             }
                 
             b_gam = Sii_lambda * 0.5; // b_gam = ( S[ i, i ] + lambda ) * 0.5
-            gam = Rf_rgamma( a_gam, 1.0 / b_gam );  // gam = rgamma( n = 1, shape = a_gam, scale = 1 / b_gam )
+            gam   = Rf_rgamma( a_gam, 1.0 / b_gam );  // gam = rgamma( n = 1, shape = a_gam, scale = 1 / b_gam )
             
             vector<double> K_11_inv_X_K_12( p1 );   // K_11_inv_X_K_12 = K_11_inv %*% K_12;
             F77_NAME(dgemv)( &transN, &p1, &p1, &alpha, &K_11_inv[0], &p1, &K_12[0], &one, &beta, &K_11_inv_X_K_12[0], &one );
@@ -135,8 +135,11 @@ void ggm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[],
             
             for( k = 0; k < row_i; k++ )
             {
-                w1 = one_g_prior_c * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_1 ) / sqrt_v1;
-                w2 = g_prior_c     * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_2 ) / sqrt_v2;
+                ik = k * dim + row_i;
+                //w1 = one_g_prior_c * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_1 ) / sqrt_v1;
+                //w2 = g_prior_c     * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_2 ) / sqrt_v2;
+                w1 = ( 1.0 - g_prior[ ik ] ) * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_1 ) / sqrt_v1;
+                w2 = g_prior[ ik ]           * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_2 ) / sqrt_v2;
                 
                 prob_e = w2 / ( w1 + w2 );
                 G_ij = ( unif_rand() < prob_e ) ? 1 : 0;
@@ -148,8 +151,11 @@ void ggm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[],
             for( k = row_i + 1; k < dim; k++ )
             {
                 k_p1 = k - 1;
-                w1 = one_g_prior_c * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_1 ) / sqrt_v1;
-                w2 = g_prior_c     * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_2 ) / sqrt_v2;
+                ik = k * dim + row_i;
+                //w1 = one_g_prior_c * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_1 ) / sqrt_v1;
+                //w2 = g_prior_c     * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_2 ) / sqrt_v2;
+                w1 = ( 1.0 - g_prior[ ik ] ) * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_1 ) / sqrt_v1;
+                w2 = g_prior[ ik ]           * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_2 ) / sqrt_v2;
                 
                 prob_e = w2 / ( w1 + w2 );
                 G_ij = ( unif_rand() < prob_e ) ? 1 : 0;
@@ -186,7 +192,7 @@ void ggm_spike_slab_map( int *iter, int *burnin, int G[], double K[], double S[]
                         double K_hat[], double p_links[], int *n,
                         int all_graphs[], double all_weights[], 
                         char *sample_graphs[], double graph_weights[], int *size_sample_g,
-                        double *v1, double *v2, double *lambda, double *g_prior, int *print )
+                        double *v1, double *v2, double *lambda, double g_prior[], int *print )
 {
     double var_1    = *v1;
     double var_2    = *v2;
@@ -195,15 +201,15 @@ void ggm_spike_slab_map( int *iter, int *burnin, int G[], double K[], double S[]
     double a_gam         = 0.5 * *n + 1.0; 
     double sqrt_v1       = sqrt( var_1 );
     double sqrt_v2       = sqrt( var_2 );
-    double g_prior_c     = *g_prior;
-    double one_g_prior_c = 1.0 - g_prior_c;
+    //double g_prior_c     = *g_prior;
+    //double one_g_prior_c = 1.0 - g_prior_c;
     
     double alpha = 1.0, beta = 0.0, alpha1 = -1.0;
     double w1, w2, prob_e, inv_V_ij, sigmaii_inv, Sii_lambda, b_gam, gam, K0ii;
     
     int print_c = *print, iteration = *iter, burn_in = *burnin;
     int info, one = 1, dim = *p, pxp = dim * dim;
-    int p1 = dim - 1, p1xp1 = p1 * p1, i, j, row_i, ii, k, k_p1, G_ij;
+    int p1 = dim - 1, p1xp1 = p1 * p1, i, j, row_i, ii, k, ik, k_p1, G_ij;
     
     char transT = 'T', transN = 'N', sideU = 'U', diagN = 'N';																	
 
@@ -309,8 +315,9 @@ void ggm_spike_slab_map( int *iter, int *burnin, int G[], double K[], double S[]
             
             for( k = 0; k < row_i; k++ )
             {
-                w1 = one_g_prior_c * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_1 ) / sqrt_v1;
-                w2 = g_prior_c     * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_2 ) / sqrt_v2;
+                ik = k * dim + row_i;
+                w1 = ( 1.0 - g_prior[ ik ] ) * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_1 ) / sqrt_v1;
+                w2 = g_prior[ ik ]     * exp( - 0.5 * K_12[ k ] * K_12[ k ] / var_2 ) / sqrt_v2;
                 
                 prob_e = w2 / ( w1 + w2 );
                 G_ij = ( unif_rand() < prob_e ) ? 1 : 0;
@@ -322,8 +329,9 @@ void ggm_spike_slab_map( int *iter, int *burnin, int G[], double K[], double S[]
             for( k = row_i + 1; k < dim; k++ )
             {
                 k_p1 = k - 1;
-                w1 = one_g_prior_c * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_1 ) / sqrt_v1;
-                w2 = g_prior_c     * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_2 ) / sqrt_v2;
+                ik = k * dim + row_i;
+                w1 = ( 1.0 - g_prior[ ik ] ) * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_1 ) / sqrt_v1;
+                w2 = g_prior[ ik ]     * exp( - 0.5 * K_12[ k_p1 ] * K_12[ k_p1 ] / var_2 ) / sqrt_v2;
                 
                 prob_e = w2 / ( w1 + w2 );
                 G_ij = ( unif_rand() < prob_e ) ? 1 : 0;
@@ -390,6 +398,4 @@ void ggm_spike_slab_map( int *iter, int *burnin, int G[], double K[], double S[]
     
 }
 
-
-       
 } // End of exturn "C"
