@@ -7,7 +7,6 @@ Check these declarations against the C/Fortran source code.
 
 /* .C calls */
 extern void check_nthread(void *);
-extern void check_os(void *);
 extern void copula(void *, void *, void *, void *, void *, void *);
 extern void gcgm_spike_slab_ma(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void gcgm_spike_slab_map(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
@@ -18,7 +17,6 @@ extern void omp_set_num_cores(void *);
 
 static const R_CMethodDef CEntries[] = {
     {"check_nthread",       (DL_FUNC) &check_nthread,        1},
-    {"check_os",            (DL_FUNC) &check_os,             1},
     {"copula",              (DL_FUNC) &copula,               6},
     {"gcgm_spike_slab_ma",  (DL_FUNC) &gcgm_spike_slab_ma,  18},
     {"gcgm_spike_slab_map", (DL_FUNC) &gcgm_spike_slab_map, 23},
